/**
 * Informatique Industrielle et Java
 * chapitre 5
 * Projet: gestion de conflits sur un port de communication
 *
 * Cette classe utilise la mthode getPortIdentifiers pour 
 * rassembler les ports disponibles sur le systme est les
 * prsente dans un format accessible par une JList, c'est--dire
 * suivant le modle AbstractListModel
 *
 * @author F.Mallet
 * @version 2003.04
 */
import javax.comm.CommPortIdentifier;
import javax.swing.AbstractListModel;
import java.util.ArrayList;
import java.util.Enumeration;

public class PortOrganisateur extends AbstractListModel {
   // Contient un gestionnaire de conflit pour chaque port accessible
	private ArrayList elements = new ArrayList();
	
	// Le constructeur parcours la liste des ports accessibles
	// et cr un gestionnaire de conflit pour chaque port
	public PortOrganisateur(String nom) {
		for (Enumeration en = CommPortIdentifier.getPortIdentifiers();
			  en.hasMoreElements();
			  /* l'numration volue avec la mthode nextElement */) {
			  
			  CommPortIdentifier ident = (CommPortIdentifier)en.nextElement();
			  
			  elements.add(new GestionnaireConflits(ident, nom));
		}
	}
	
	/** ouvre le port numro index dans la liste des ports
	  */
	public void ouvrePort(int index) {
		// L'ouverture est dlgue au gestionnaire de conflits numro index
		((GestionnaireConflits)elements.get(index)).ouvrePort();
		
		// Les couteurs du modle de liste sont informs d'une modification
		// En particulier, si une JList est associe, elle est redessine
		fireContentsChanged(this, index, index);
	}
	
	/** ferme le port numro index dans la liste des ports
	  */
	public void fermePort(int index) {
		// La fermeture est dlgue au gestionnaire de conflits numro index
		((GestionnaireConflits)elements.get(index)).fermePort();

		// Les couteurs du modle de liste sont informs d'une modification
		// En particulier, si une JList est associe, elle est redessine
		fireContentsChanged(this, index, index);
	}
		
	/** Les deux mthode getElementAt et getSize dont abstraites
	 *  dans la classe AbstractListModel
	 * @return le index-ieme gestionnaire de conflits est retourn */
	public Object getElementAt(int index) {
		return elements.get(index);
	}
	public int getSize() {
		return elements.size();
	}
}
